A framework for estimating difference-in-differences with unpoolable data, based on Karim, Webb, Austin, and Strumpf (2024) tools:::Rd_expr_doi("10.48550/arXiv.2403.15910"). Supports common or staggered adoption, multiple groups, and the inclusion of covariates. Also computes p-values for the aggregate average treatment effect on the treated via the randomization inference procedure described in MacKinnon and Webb (2020) tools:::Rd_expr_doi("10.1016/j.jeconom.2020.04.024").
Maintainer: Eric Jamieson ericbrucejamieson@gmail.com [copyright holder]
Useful links: