Learn R Programming

undidR (version 3.0.1)

undid_date_formats: Shows valid date formats

Description

The undid_date_formats() function returns a list of all valid date formats that can be used within the undidR package.

Usage

undid_date_formats()

Arguments

Value

A named list containing valid date formats:

  • General_Formats: General date formats compatible with the package.

  • R_Specific_Formats: Date formats specific to R.

  • Other_Formats: Formats seen sometimes in Stata.

Details

The date formats returned by this function are used to ensure consistency in date processing within the undidR package.

Examples

Run this code
undid_date_formats()

Run the code above in your browser using DataLab