powered by
The undid_date_formats() function returns a list of all valid date formats that can be used within the undidR package.
undid_date_formats()
undidR
A named list containing valid date formats:
General_Formats: General date formats compatible with the package.
General_Formats
R_Specific_Formats: Date formats specific to R.
R_Specific_Formats
Other_Formats: Formats seen sometimes in Stata.
Other_Formats
The date formats returned by this function are used to ensure consistency in date processing within the undidR package.
Run the code above in your browser using DataLab